#
# spec file for package libfilezilla
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define major		0
%define libname		%{name}%{major}
%define develname	%{name}-devel
Name:           libfilezilla
Version:        0.9.0
Release:        1.4
Summary:        C++ library for filezilla
License:        GPL-2.0+
Group:          System/Libraries
Url:            https://lib.filezilla-project.org/
Source0:        http://download.filezilla-project.org/libfilezilla/%{name}-%{version}.tar.bz2
Source1:        COPYING
Patch0:         libfilezilla-date-time.patch
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  doxygen
BuildRequires:  fdupes
BuildRequires:  graphviz
BuildRequires:  libtool
BuildRequires:  pkg-config
BuildRequires:  pkgconfig(cppunit)
%if 0%{?suse_version} <= 1320
# FileZilla requires C++14 support.
BuildRequires:  gcc5-c++
%else
BuildRequires:  gcc-c++
%endif

%description
libfilezilla is a free, open source C++ library, offering some basic
functionality to build high-performing, platform-independent programs.
libfilezilla is needed for filezilla (ftp client and server) to build.
Some of the highlights include:

* A typesafe, multi-threaded event system that's very simple to use yet
  extremely efficient.
* Timers for periodic events.
* A datetime class that not only tracks timestamp but also their accuracy,
  which simplifies dealing with timestamps originating from different sources.
* Simple process handling for spawning child processes with redirected I/O.


%package -n	%{libname}
Summary:        C++ library for filezilla
Group:          System/Libraries

%description -n	%{libname}
libfilezilla is a free, open source C++ library, offering some basic
functionality to build high-performing, platform-independent programs.
libfilezilla is needed for filezilla (ftp client and server) to build.
Some of the highlights include:

* A typesafe, multi-threaded event system that's very simple to use yet
  extremely efficient.
* Timers for periodic events.
* A datetime class that not only tracks timestamp but also their accuracy,
  which simplifies dealing with timestamps originating from different sources.
* Simple process handling for spawning child processes with redirected I/O.


%package -n	%{develname}
Summary:        Development package for %{name}
Group:          Development/Libraries
Requires:       %{libname} = %{version}-%{release}

%description -n	%{develname}
Files needed for development with %{name}.


%prep
%setup -q
%patch0
#copy in up to date GPL-2.0 license.
cp -v %{SOURCE1} .

%build
%if 0%{?suse_version} <= 1320
export CC="gcc-5"
export CXX="g++-5"
# Default ABI through G++4.9, thus the one wxWidgets uses.
export CXXFLAGS="%{optflags} -fabi-version=2 -fabi-compat-version=2"
%endif
autoreconf -fi
%configure --disable-static
make %{?_smp_mflags}

pushd doc
make %{?_smp_mflags} html
popd

%install
%makeinstall

# we don't want this
find %{buildroot} -type f -name "*.la" -delete -print
mkdir -p %{buildroot}%{_docdir}/%{develname}
cp -r doc/doxygen-doc/* %{buildroot}%{_docdir}/%{develname}/
rm -f %{buildroot}%{_docdir}/%{develname}/latex/refman.tex
%fdupes -s %{buildroot}%{_docdir}/%{develname}

%post -n %{libname} -p /sbin/ldconfig

%postun -n %{libname} -p /sbin/ldconfig

%files -n %{libname}
%defattr(-,root,root)
%doc AUTHORS ChangeLog NEWS README COPYING
%{_libdir}/%{name}.so.%{major}*

%files -n %{develname}
%defattr(-,root,root)
%dir %{_docdir}/%{develname}
%{_docdir}/%{develname}/*
%{_includedir}/%{name}/
%{_libdir}/%{name}.so
%{_libdir}/pkgconfig/%{name}.pc

%changelog
* Tue Dec  6 2016 ecsos@opensuse.org
- update to 0.9.0
  * New features:
  - Added parameter to fz::to_integral to specify which value is
    returned on error.
  - Added fz::remove_file
  - Added fz::hex_encode and fz::hex_decode
* Sun Nov 20 2016 ecsos@opensuse.org
- update to 0.8.0
  * New features:
  - Added fz::str_toupper_ascii to complement
    fz::str_tolower_ascii
  - Added fz::trim and fz::trimmed for removing leading and
    trailing whitespace from string
  - Added fz::str_is_ascii
  * Bugfixes and minor changes:
  - Fixed zero-padding for x and X string format conversion
    specifiers
- update to 0.7.1
  * Bugfixes and minor changes:
  - OS X: Work around a nasty bug in XCode where programs
    explicitly compiled for older versions of OS X were silently
    pulling in features exclusive to the new version, resulting
    in crashes at runtime
  - MSW: Fix detection of thread creation failures
* Sun Oct  2 2016 ecsos@opensuse.org
- update to 0.7.0
  * New features:
  - Add fz::base64_decode and fz::base64_encode
  - Add fz::strtok string tokenizer
  - Added non-throwing fz::to_integral
  - Implemented + (always sign) and - (left align) flags for
    fz::sprintf
* Fri Jul 29 2016 ecsos@opensuse.org
- update to 0.6.1
  * Bugfixes and minor changes:
  - Fix UTF-8 conversion functions and added a testcase
- update to 0.6.0
  * New features:
  - Add fz::sprintf, a safe replacement for for the C sprintf
    function
* Tue Jun 28 2016 ecsos@opensuse.org
- update to 0.5.3
  * New features:
  - Add fz::replace_substrincs to search and replace substrings
    in std::(w)string
  * Bugfixes and minor changes:
  - Explicitly request large file support on 32bit systems
* Sat May 28 2016 ecsos@opensuse.org
- update to 0.5.2
  * New features:
  - Add fz::shared_optional::is_same that checks whether
    two instances share the same underlying pointer value, like
    a shallow equal.
  - Add fz::int_to_hex_char as reverse to fz::hex_char_to_int
* Tue May 10 2016 ecsos@opensuse.org
- Update to version 0.5.1
  - Add constructore to sparse_optional taking pointers
  - Fix compilation on systems where iconv's second argument is
    const
* Wed Apr 27 2016 joerg.lorenzen@ki.tng.de
- Update to version 0.5.0
  - Handle timestamps where midnight is represented as 24:00:00.000
    of the previous day.
  - Fix inverted return value of fz::datetime::empty().
  - Increase performance of event loop if not using timers.
  - Better compatibility with runtimes that change the src pointer
    passed to mbsrtowcs or wcsrtombs.
* Fri Mar 11 2016 davejplater@gmail.com
- Added libfilezilla-date-time.patch.
* Sun Feb 28 2016 ecsos@opensuse.org
- update to 0.4.0.1
- Upstream changes:
  0.4.0.1 (2016-02-22)
  Fix compile error in testcase
  0.4.0 (2016-02-21)
  Added shared_optional and sparse_optional classes
  For more details see svn log:
  https://svn.filezilla-project.org/svn/libfilezilla
* Sun Feb 14 2016 davejplater@gmail.com
- Initial package created from PCLinuxOS src rpm
- Needed for filezilla to build.
